@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright (c) 2010—2012 Andrey Mikhailenko and contributors
+#  Copyright (c) 2010—2013 Andrey Mikhaylenko and contributors
 #
 #  This file is part of Argh.
 #
@@ -8,22 +8,12 @@
 #  General Public License version 3 (LGPLv3) as published by the Free
 #  Software Foundation. See the file README for copying conditions.
 #
-"""
-API reference
-=============
-
-.. automodule:: argh.decorators
-   :members:
-
-.. automodule:: argh.helpers
-   :members:
-
-.. automodule:: argh.exceptions
-   :members:
-
-"""
-from .exceptions import *
-from .helpers import *
+from .assembling import *
 from .decorators import *
+from .dispatching import *
+from .exceptions import *
+from .interaction import *
+from .helpers import *
 
-__version__ = '0.17.2'
+
+__version__ = '0.23.2'
