@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-#  Copyright (c) 2010—2012 Andrey Mikhailenko and contributors
+#  Copyright (c) 2010—2013 Andrey Mikhaylenko and contributors
 #
 #  This file is part of Argh.
 #
@@ -8,11 +8,18 @@
 #  General Public License version 3 (LGPLv3) as published by the Free
 #  Software Foundation. See the file README for copying conditions.
 #
+"""
+Utilities
+~~~~~~~~~
+"""
 import argparse
+import inspect
+
+from argh import compat
 
 
 def get_subparsers(parser, create=False):
-    """Returns the :class:`argparse._SupParsersAction` instance for given
+    """Returns the :class:`argparse._SubParsersAction` instance for given
     :class:`ArgumentParser` instance as would have been returned by
     :meth:`ArgumentParser.add_subparsers`. The problem with the latter is that
     it only works once and raises an exception on the second attempt, and the
@@ -33,3 +40,20 @@ def get_subparsers(parser, create=False):
     else:
         if create:
             return parser.add_subparsers()
+
+
+def get_arg_names(function):
+    """Returns argument names for given function.  Omits special arguments
+    of instance methods (`self`) and static methods (usually `cls` or something
+    like this).
+    """
+    spec = compat.getargspec(function)
+    names = spec.args
+
+    if not names:
+        return []
+
+    if inspect.ismethod(function):
+        return names[1:]
+    else:
+        return names
